@@ -26,6 +26,7 @@ from tortoise.exceptions import (
     IncompleteInstanceError,
     IntegrityError,
     OperationalError,
+    ParamsError,
     TransactionManagementError,
 )
 from tortoise.fields.base import Field
@@ -47,6 +48,7 @@ from tortoise.signals import Signals
 from tortoise.transactions import current_transaction_map, in_transaction
 
 MODEL = TypeVar("MODEL", bound="Model")
+EMPTY = object()
 
 
 # TODO: Define Filter type object. Possibly tuple?
@@ -142,7 +144,7 @@ def _get_comments(cls: "Type[Model]") -> Dict[str, str]:
     for cls_ in reversed(cls.__mro__):
         if cls_ is object:
             continue
-        matches = re.findall(rf"((?:(?!\n|^)[^\w\n]*#:.*?\n)+?)[^\w\n]*(\w+)\s*[:=]", source)
+        matches = re.findall(r"((?:(?!\n|^)[^\w\n]*#:.*?\n)+?)[^\w\n]*(\w+)\s*[:=]", source)
         for match in matches:
             field_name = match[1]
             # Extract text
@@ -739,7 +741,30 @@ class Model(metaclass=ModelMeta):
         except (DoesNotExist, ValueError):
             raise KeyError(f"{cls._meta.full_name} has no object {repr(key)}")
 
-    def update_from_dict(self, data: dict) -> MODEL:
+    def clone(self: MODEL, pk: Any = EMPTY) -> MODEL:
+        """
+        Create a new clone of the object that when you do a ``.save()`` will create a new record.
+
+        :param pk: An optionally required value if the model doesn't generate its own primary key.
+            Any value you specify here will always be used.
+        :return: A copy of the current object without primary key information.
+        :raises ParamsError: If pk is required but not provided.
+        """
+        obj = copy(self)
+        if pk is EMPTY:
+            pk_field: Field = self._meta.pk
+            if pk_field.generated is False and pk_field.default is None:
+                raise ParamsError(
+                    f"{self._meta.full_name} requires explicit primary key. Please use .clone(pk=<value>)"
+                )
+            else:
+                obj.pk = None
+        else:
+            obj.pk = pk
+        obj._saved_in_db = False
+        return obj
+
+    def update_from_dict(self: MODEL, data: dict) -> MODEL:
         """
         Updates the current model with the provided dict.
         This can allow mass-updating a model from a dict, also ensuring that datatype conversions happen.
@@ -755,7 +780,7 @@ class Model(metaclass=ModelMeta):
         :raises ValueError: When a passed parameter is not type compatible
         """
         self._set_kwargs(data)
-        return self  # type: ignore
+        return self
 
     @classmethod
     def register_listener(cls, signal: Signals, listener: Callable):
@@ -814,6 +839,8 @@ class Model(metaclass=ModelMeta):
         self,
         using_db: Optional[BaseDBAsyncClient] = None,
         update_fields: Optional[List[str]] = None,
+        force_create: bool = False,
+        force_update: bool = False,
     ) -> None:
         """
         Creates/Updates the current model object.
@@ -823,8 +850,11 @@ class Model(metaclass=ModelMeta):
             This is the subset of fields that should be updated.
             If the object needs to be created ``update_fields`` will be ignored.
         :param using_db: Specific DB connection to use instead of default bound
+        :param force_create: Forces creation of the record
+        :param force_update: Forces updating of the record
 
         :raises IncompleteInstanceError: If the model is partial and the fields are not available for persistance.
+        :raises IntegrityError: If the model can't be created or updated (specifically if force_create or force_update has been set)
         """
         db = using_db or self._meta.db
         executor = db.executor_class(model=self.__class__, db=db)
@@ -844,13 +874,29 @@ class Model(metaclass=ModelMeta):
                     f"{self.__class__.__name__} is a partial model, can only be saved with the relevant update_field provided"
                 )
         await self._pre_save(using_db, update_fields)
-        if self._saved_in_db:
-            await executor.execute_update(self, update_fields)
-            created = False
-        else:
+
+        if force_create:
             await executor.execute_insert(self)
             created = True
-            self._saved_in_db = True
+        elif force_update:
+            rows = await executor.execute_update(self, update_fields)
+            if rows == 0:
+                raise IntegrityError(f"Can't update object that doesn't exist. PK: {self.pk}")
+            created = False
+        else:
+            if self._saved_in_db or update_fields:
+                if self.pk is None:
+                    await executor.execute_insert(self)
+                    created = True
+                else:
+                    await executor.execute_update(self, update_fields)
+                    created = False
+            else:
+                # TODO: Do a merge/upsert operation here instead. Let the executor determine an optimal strategy for each DB engine.
+                await executor.execute_insert(self)
+                created = True
+
+        self._saved_in_db = True
         await self._post_save(using_db, created, update_fields)
 
     async def delete(self, using_db: Optional[BaseDBAsyncClient] = None) -> None:
@@ -933,7 +979,7 @@ class Model(metaclass=ModelMeta):
         instance = cls(**kwargs)
         instance._saved_in_db = False
         db = kwargs.get("using_db") or cls._meta.db
-        await instance.save(using_db=db)
+        await instance.save(using_db=db, force_create=True)
         return instance
 
     @classmethod
